Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7267)

Unified Diff: chrome/installer/util/delete_tree_work_item.h

Issue 11359217: Move scoped_temp_dir from base to base/files (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/installer/util/delete_tree_work_item.h
diff --git a/chrome/installer/util/delete_tree_work_item.h b/chrome/installer/util/delete_tree_work_item.h
index 2bf7471c9c25aea9e0142fa704dfee8b3177f332..aba34caf518eeaee66c19662f32e0dde3a9b3ca3 100644
--- a/chrome/installer/util/delete_tree_work_item.h
+++ b/chrome/installer/util/delete_tree_work_item.h
@@ -8,8 +8,8 @@
#include <vector>
#include "base/file_path.h"
+#include "base/files/scoped_temp_dir.h"
#include "base/memory/scoped_ptr.h"
-#include "base/scoped_temp_dir.h"
#include "chrome/installer/util/work_item.h"
// A WorkItem subclass that recursively deletes a file system hierarchy at the
@@ -47,11 +47,11 @@ class DeleteTreeWorkItem : public WorkItem {
// Contains the temp directories for the backed-up key files. The directories
// are created and populated in Do() as-needed. We don't use a standard
- // container for this since ScopedTempDir isn't CopyConstructible.
- scoped_array<ScopedTempDir> key_backup_paths_;
+ // container for this since base::ScopedTempDir isn't CopyConstructible.
+ scoped_array<base::ScopedTempDir> key_backup_paths_;
// The temporary directory into which the original root_path_ has been moved.
- ScopedTempDir backup_path_;
+ base::ScopedTempDir backup_path_;
// Set to true once root_path_ has been copied into backup_path_.
bool copied_to_backup_;
« no previous file with comments | « chrome/installer/util/create_dir_work_item_unittest.cc ('k') | chrome/installer/util/delete_tree_work_item.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698